@@ -25,7 +25,7 @@ end
 class OggInfoError < StandardError ; end
 
 class OggInfo
-  VERSION = "0.6.8"
+  VERSION = "0.6.10"
   extend Forwardable
   include Ogg
   
@@ -44,7 +44,7 @@ class OggInfo
     @length = nil
     @bitrate = nil
     filesize = File.size(@filename)
-    File.open(@filename) do |file|
+    File.open(@filename, 'rb') do |file|
       begin
      	info = read_headers(file)
         @samplerate = info[:samplerate]
